package treeplus.visualization;

import java.awt.geom.Point2D;

import prefuse.Constants;
import prefuse.Visualization;
import prefuse.action.Action;
import prefuse.data.tuple.TupleSet;
import prefuse.visual.VisualItem;
import treeplus.visualization.demo.TreePlusRunner;

/**
 * {@link Action}, that determines the new position of the whole rendered
 * visualization by calculating the size of the current visualization. Used to
 * auto pan the new expanded tree into the visible area of the current window.
 * 
 * @author Neubauer, Kstinger
 */
public class AutoPanAction extends Action {

	private Point2D m_start = new Point2D.Double();
	private Point2D m_end = new Point2D.Double();
	private Point2D m_cur = new Point2D.Double();
	private int m_bias = 150;

	private TreePlus mainWindow = null;

	/**
	 * creates the AutoPanAction using the given {@link TreePlus}
	 * 
	 * @param treeplus
	 *            the current {@link TreePlus} used to calculate the new
	 *            position
	 * @param runner
	 *            the current {@link TreePlusRunner}
	 */
	public AutoPanAction(TreePlus treeplus) {
		this.mainWindow = treeplus;
	}

	/**
	 * Runs the action. Calculates the new position of the tree and moves/pans
	 * the window to it.
	 * 
	 * @param frac
	 *            the fraction of this Action's duration that has elapsed.
	 */
	public void run(double frac) {
		TupleSet ts = m_vis.getFocusGroup(Visualization.FOCUS_ITEMS);

		if (ts.getTupleCount() == 0)
			return;
		
		if (frac < 0.01) {

			int xbias = 0, ybias = 0;

			switch (mainWindow.getOrientation()) {
			case Constants.ORIENT_LEFT_RIGHT:
				xbias = m_bias;
				break;
			case Constants.ORIENT_RIGHT_LEFT:
				xbias = -m_bias;
				break;
			case Constants.ORIENT_TOP_BOTTOM:
				ybias = m_bias;
				break;
			case Constants.ORIENT_BOTTOM_TOP:
				ybias = -m_bias;
				break;
			}

			VisualItem vi = (VisualItem) ts.tuples().next();
			m_cur.setLocation(mainWindow.getWidth() / 2,
					mainWindow.getHeight() / 2);
			mainWindow.getAbsoluteCoordinate(m_cur, m_start);
			m_end.setLocation(vi.getX() + xbias, vi.getY() + ybias);

		} else {

			m_cur.setLocation(m_start.getX() + frac
					* (m_end.getX() - m_start.getX()), m_start.getY() + frac
					* (m_end.getY() - m_start.getY()));

			mainWindow.panToAbs(m_cur);
		}
	}
}