package treeplus.visualization;

import java.awt.Color;
import java.awt.Paint;

import prefuse.util.ColorLib;

/**
 * Context class, which stores all the used colors to provide flexibility in exchanging the colors.
 * A preferences dialog for example could handle this values.
 * @author Neubauer, Kstinger
 *
 */
public class ColorContext {

	/**
	 * the color for the current active node
	 */
	public static int NodeActiveColor = ColorLib.rgb(151, 212, 131);
	
	/**
	 * the color for the nodes, incoming to the current active node
	 */
	public static int NodeInColor = ColorLib.rgb(252, 200, 200);
	
	/**
	 * the color for the nodes, outgoing from the current active node
	 */
	public static int NodeOutColor = ColorLib.rgb(200, 210, 252);
	
	/**
	 * the color for the nodes, bidirectional adjacent to the current node
	 */
	public static int NodeBiColor = ColorLib.rgb(240, 190, 250);
	
	/**
	 * the transparent color for all the standard nodes, not highlighted by any special event
	 * like search, focus, adjacent or moved
	 */
	public static int NodeTransparent = ColorLib.rgba(255,255,255,0);
	
	/**
	 * the node color of the found/matched items by the currently ongoing search
	 */
	public static int NodeSearchColor = ColorLib.rgb(150,150,150);
	
	/**
	 * the node color of all the nodes moved from this position to another
	 */
	public static int NodeMovedColor = ColorLib.rgb(255,200,30);

	/**
	 * the edge color
	 */
	public static int NormalEdgeColor = ColorLib.rgb(200,200,200);
	
	/**
	 * the color of the bar indicating the incoming amount of nodes
	 */
	public static Paint InBarColor = Color.RED;
	
	/**
	 * the color of the bar indicating the outgoing amount of nodes
	 */
	public static Paint OutBarColor = Color.BLUE;
	
	/**
	 * the color of the bar indicating the bidirectiional amount of nodes
	 */
	public static Paint BiBarColor = ColorLib.getColor(128, 0, 128);

	
}
