package treeplus.visualization;

import prefuse.Visualization;
import prefuse.action.assignment.ColorAction;
import prefuse.visual.VisualItem;
import treeplus.visualization.demo.ITreePlusRunner;
/**
 * {@link ColorAction} which colors the VisualItems depending on their properties.
 * @author Neubauer, Kstinger
 *
 */
public class NodeColorAction extends ColorAction {

	private ITreePlusRunner runner;
	
	/**
	 * Creates a NodeColorAction for the given group in the visualization. With the given
	 * {@link TreePlusRunner} some properties of the VisualItem are fetched.
	 * @param group determines the visualization group, for which the ColorAction should work
	 * @param runner the current {@link TreePlusRunner}
	 */
	public NodeColorAction(String group, ITreePlusRunner runner) {
		super(group, VisualItem.FILLCOLOR);
		this.runner = runner;
	}

	/**
	 * Returns the actual color of the given VisualItem depending on the item's properties.
	 * @param item the VisualItem to color
	 * @return the color as integer value
	 */
	public int getColor(VisualItem item) {

		Direction dir = runner.isInVisibleNodesOfClickedItem(item
				.getString(runner.getLabel()));

		if (m_vis.isInGroup(item, Visualization.SEARCH_ITEMS)) {
			return ColorContext.NodeSearchColor;
		} else if (runner.getMovedItemsList() != null) {
			int row = item.getRow();
			for (int i = 0; i < runner.getMovedItemsList().size(); i++) {
				if (runner.getMovedItemsList().get(i) == row) {
					return ColorContext.NodeMovedColor;
				}
			}
			return ColorContext.NodeTransparent;
		} else if (item.equals(runner.getActiveItem())) {
			return ColorContext.NodeActiveColor;
		} else if (dir != null) {
			if (dir == Direction.In) {
				return ColorContext.NodeInColor;
			} else if (dir == Direction.Out) {
				return ColorContext.NodeOutColor;
			} else {
				return ColorContext.NodeBiColor;
			}
		} else
			return ColorContext.NodeTransparent;
	}

}