package treeplus.visualization;

import prefuse.data.Node;
import prefuse.data.Tuple;
import prefuse.data.event.TupleSetListener;
import prefuse.data.tuple.TupleSet;
import prefuse.visual.VisualItem;
import prefuse.visual.tuple.TableNodeItem;
import treeplus.visualization.demo.ITreePlusRunner;
import treeplus.visualization.demo.TreePlusRunner;
/**
 * {@link TupleSetListener} to fetch the event of clicking on a node in the graph.
 * By clicking a node in the graph a new TreePlus-Tree is built and shown in the view.
 * @author Neubauer, Kstinger
 *
 */
public class NodeSelectionListener implements TupleSetListener {

	private ITreePlusRunner runner;

	/**
	 * Creates a new NodeSelectionListener using the given {@link TreePlusRunner}
	 * @param runner the current {@link TreePlusRunner}
	 */
	public NodeSelectionListener(ITreePlusRunner runner) {
       this.runner = runner;
    }
	
	/**
	 * The first selected item is used to create a new TreePlus-Tree.
	 * @param the TupleSet that has changed
	 * @param an array (potentially zero-length) of added tuples
	 * @param an array (potentially zero-length) of removed tuples
	 */
	 public void tupleSetChanged(TupleSet ts, Tuple[] add, Tuple[] rem)
     { 
         for ( int i=0; i<rem.length; ++i )
             ((VisualItem)rem[i]).setFixed(false);
         for ( int i=0; i<add.length; ) {
             ((VisualItem)add[i]).setFixed(false);
             ((VisualItem)add[i]).setFixed(true);
             // only the first selected item will be the start node for the 
             // spanning tree
             Node n = runner.getGraph().getNode(((VisualItem)add[i]).getRow());
 			
 			 runner.setAdjacentNodesOfSelectedItem(null);
 			 runner.setSelectedGraphNodeForSpanningTree(n);

 			 break;
         }
         if ( ts.getTupleCount() == 0 ) {
             ts.addTuple(rem[0]);
             ((VisualItem)rem[0]).setFixed(false);
         }
         
     }
}
