package treeplus.visualization;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.event.MouseEvent;

import javax.swing.JMenuItem;
import javax.swing.JPopupMenu;
import javax.swing.SwingUtilities;

import prefuse.controls.ControlAdapter;
import prefuse.data.Node;
import prefuse.visual.NodeItem;
import prefuse.visual.VisualItem;
import treeplus.visualization.demo.ITreePlusRunner;

/**
 * {@link ControlAdapter} that implements a popup menu which appears on right click to make the currently selected
 * node the new root node of the tree. 
 * @author Neubauer, Kstinger
 *
 */
public class PopupMenuControler extends ControlAdapter implements
		ActionListener {

	private JPopupMenu nodePopupMenu;
	private VisualItem clickedItem;
	private ITreePlusRunner runner;
	
	/**
	 * creates an instance of the controler by the use of the 
	 * {@link ITreePlusRunner} instance
	 * @param runner used to determine callback methods to the visualization
	 */
	public PopupMenuControler(ITreePlusRunner runner) {

		this.runner = runner;
		// create popupMenu for nodes
		nodePopupMenu = new JPopupMenu();

		JMenuItem makeRoot = new JMenuItem("Make root", 'r');
		
		makeRoot.setActionCommand("root");
		
		nodePopupMenu.add(makeRoot);

		makeRoot.setMnemonic(KeyEvent.VK_R);
		makeRoot.addActionListener(this);
	}


	/**
	 * shows the popup-menu, when a visual item is right-clicked
	 * @param item the selected VisualItem
	 * @param e MouseEvent of the action
	 */
	@Override
	public void itemClicked(VisualItem item, MouseEvent e) {

		if (SwingUtilities.isRightMouseButton(e)) {
			if (item instanceof NodeItem) {
				clickedItem = item;
				nodePopupMenu.show(e.getComponent(), e.getX(), e.getY());
			}
		}
	}

	/**
	 * executes the actions performed by the click-event.
	 * @param e the action event
	 */
	@Override
	public void actionPerformed(ActionEvent e) {
		if (e.getActionCommand().startsWith("root")) {
			Node n = runner.getGraph().getNode(clickedItem.getRow());
			
			runner.setAdjacentNodesOfSelectedItem(null);
			runner.setSelectedGraphNodeForSpanningTree(n);
		} 
	}
}
