package treeplus.visualization;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.JComponent;

import prefuse.data.Graph;
import treeplus.visualization.demo.ITreePlusRunner;

/**
 * The {@link AbstractAction} to switch between the two views "TreeView" and "GrapView". 
 * In the "TreeView" the TreePlus is shown and 
 * in the "GraphView" the corresponding graph to the tree is shown.
 * @author Neubauer, Kstinger
 *
 */
public class SwitchViewAction extends AbstractAction {

	public static final int SWITCH_TO_GRAPH = 1;
	public static final int SWITCH_TO_TREE = 0;

	private ITreePlusRunner runner;

	/**
	 * creates the SwitchViewAction using the given {@link TreePlusRunner}
	 * @param runner runner the current {@link TreePlusRunner} used to set the different views into the panel
	 */
	public SwitchViewAction(ITreePlusRunner runner) {
		this.runner = runner;
		this.putValue(AbstractAction.NAME, "Show graph");
	}

	/**
	 * Switches between the views.
	 */
	public void actionPerformed(ActionEvent actionEvent) {
		if (actionEvent.getActionCommand().equals("Show graph")) {
			switchName(SWITCH_TO_TREE);
			
			if(runner.getActualGraphView()==null){
				JComponent panel = null;
	
				try {
					Graph g = runner.getGraph();
					panel = GraphView.demo(g, runner.getLabel(), runner);
				} catch (Exception e) {
					e.printStackTrace();
					System.exit(1);
				}
				
				runner.setActualGraphView(panel);
			}
			
			runner.getEnclosingFrame().setContentPane(runner.getActualGraphView());
			
		} else {
			switchName(SWITCH_TO_GRAPH);
			runner.getEnclosingFrame().setContentPane(runner.getActualTreeView());			
		}
		
		runner.getEnclosingFrame().validate();
		runner.getEnclosingFrame().repaint();
	}

	/**
	 * Switches between the two names of the action to enable the switching 
	 * between the two views of the visualization
	 * @param status 0 if the name should be changed to "Show tree" and 
	 * 					1 if the name should be changed to "Show graph"
	 */
	public void switchName(int status) {
		if (status == 0) {
			this.putValue(AbstractAction.NAME, "Show tree");
		}
		if (status == 1) {
			this.putValue(AbstractAction.NAME, "Show graph");
		}
	}

}
