package treeplus.visualization;

import java.awt.event.MouseEvent;

import prefuse.Display;
import prefuse.controls.ToolTipControl;
import prefuse.data.Node;
import prefuse.visual.VisualItem;
import treeplus.visualization.demo.ITreePlusRunner;

/**
 * Tooltip for the {@link TreePlus} showing tooltip info on rendered Node items 
 * @author Harald
 *
 */
public class TreePlusToolTipControl extends ToolTipControl {

	private ITreePlusRunner runner;

	/**
	 * creates an instance of the tooltip control which uses the {@link ITreePlusRunner} to
	 * determine the tooltip for the visual item.
	 * @param runner
	 */
	public TreePlusToolTipControl(ITreePlusRunner runner) {
		super(runner.getLabel());
		this.runner = runner;
	}

	/**
	 * fired, if an item has lost focus. The currently displayed tooltip is being removed.
	 */
	@Override
	public void itemExited(VisualItem item, MouseEvent e) {
		Display d = (Display) e.getSource();
		d.setToolTipText(null);
	}

	/**
	 * fired, when an item is hovered by the mouse.
	 * Uses the {@link ITreePlusRunner} to determine the tooltip text for the currently highlighted
	 * visual item.
	 * @param item the item for which to determine the tooltip
	 * @param e the mouse event 
	 */
	@Override
	public void itemEntered(VisualItem item, MouseEvent e) {

		if (item instanceof Node) {
			Display d = (Display) e.getSource();
			d.setToolTipText(runner.getToolTipForNodeRow(item.getRow()));
		}

	}
}
